@@ -15,7 +15,7 @@ extends 'Zing::Watcher';
 
 use Zing::Kernel;
 
-our $VERSION = '0.06'; # VERSION
+our $VERSION = '0.07'; # VERSION
 
 # ATTRIBUTES
 
@@ -480,16 +480,16 @@ scale your deployments without changing your implementations.
 =head2 configuration
 
   # configure where the command-line tool finds catridges
-  # ZING_HOME=/tmp
+  ZING_HOME=/tmp
 
   # configure the hostname used in process registration
-  # ZING_HOST=0.0.0.0
-  # ZING_HOST=68.80.90.100
+  ZING_HOST=0.0.0.0
+  ZING_HOST=68.80.90.100
 
   # configure Redis driver without touching your source code
-  # ZING_REDIS='every=1_000_000,reconnect=60'
-  # ZING_REDIS='sentinels=127.0.0.1:12345|127.0.0.1:23456,sentinels_cnx_timeout=0.1'
-  # ZING_REDIS='server=192.168.0.1:6379,debug=0'
+  ZING_REDIS='every=1_000_000,reconnect=60'
+  ZING_REDIS='sentinels=127.0.0.1:12345|127.0.0.1:23456,sentinels_cnx_timeout=0.1'
+  ZING_REDIS='server=192.168.0.1:6379,debug=0'
 
 This distribution provides environment variables that let you customize how
 Zing operates and behaves without the need to modify source code. These
