@@ -16,7 +16,7 @@ extends 'Zing::Watcher';
 use Zing::Channel;
 use Zing::Logic::Kernel;
 
-our $VERSION = '0.06'; # VERSION
+our $VERSION = '0.07'; # VERSION
 
 # ATTRIBUTES
 
@@ -27,7 +27,7 @@ has 'journal' => (
 );
 
 fun new_journal($self) {
-  Zing::Channel->new(name => 'journal')
+  Zing::Channel->new(name => '$journal')
 }
 
 has 'scheme' => (
