@@ -23,7 +23,7 @@ use Zing::Mailbox;
 use Zing::Node;
 use Zing::Registry;
 
-our $VERSION = '0.06'; # VERSION
+our $VERSION = '0.07'; # VERSION
 
 # ATTRIBUTES
 
@@ -50,7 +50,7 @@ has 'journal' => (
 );
 
 fun new_journal($self) {
-  Zing::Channel->new(name => 'journal')
+  Zing::Channel->new(name => '$journal')
 }
 
 has 'log' => (
